# Release notes

## 1.0.2

- Fixed the inclusion of the metadata inventory in the distribution on PyPI.
- When a private copy of the metadata inventory is loaded, the registration
  inventory is now also updated correctly.

## 1.0.1

- Updated the metadata database to version 1.0. This has no major differences
  from the previous version of the metadata database (version 0.9).

## 1.0

First release of the `hoa-tools` package 🚀
